searchData={"items":[{"type":"module","title":"Supabase","doc":"The main entrypoint for the Supabase SDK library.","ref":"Supabase.html"},{"type":"module","title":"Starting a Client - Supabase","doc":"You then can start a Client calling `Supabase.init_client/3`:\n\n    iex> Supabase.init_client(\"base_url\", \"api_key\", %{db: %{schema: \"public\"}})\n    {:ok, %Supabase.Client{}}","ref":"Supabase.html#module-starting-a-client"},{"type":"module","title":"Acknowledgements - Supabase","doc":"This package represents the base SDK for Supabase. That means\nthat it not includes all of the functionality of the Supabase client integrations, so you need to install each feature separetely, as:\n\n- [Supabase.GoTrue](https://hexdocs.pm/supabase_gotrue)\n- [Supabase.Storage](https://hexdocs.pm/supabase_storage)\n- [Supabase.PostgREST](https://hexdocs.pm/supabase_postgrest)\n- `Realtime` - TODO\n- `UI` - TODO","ref":"Supabase.html#module-acknowledgements"},{"type":"module","title":"Supabase Storage - Supabase","doc":"Supabase Storage is a service for developers to store large objects like images, videos, and other files. It is a hosted object storage service, like AWS S3, but with a simple API and strong consistency.","ref":"Supabase.html#module-supabase-storage"},{"type":"module","title":"Supabase PostgREST - Supabase","doc":"PostgREST is a web server that turns your PostgreSQL database directly into a RESTful API. The structural constraints and permissions in the database determine the API endpoints and operations.","ref":"Supabase.html#module-supabase-postgrest"},{"type":"module","title":"Supabase Realtime - Supabase","doc":"Supabase Realtime provides a realtime websocket API powered by PostgreSQL notifications. It allows you to listen to changes in your database, and instantly receive updates as soon as they happen.","ref":"Supabase.html#module-supabase-realtime"},{"type":"module","title":"Supabase Auth/GoTrue - Supabase","doc":"Supabase Auth is a feature-complete user authentication system. It provides email & password sign in, email verification, password recovery, session management, and more, out of the box.","ref":"Supabase.html#module-supabase-auth-gotrue"},{"type":"module","title":"Supabase UI - Supabase","doc":"Supabase UI is a set of UI components that help you quickly build Supabase-powered applications. It is built on top of Tailwind CSS and Headless UI, and is fully customizable. The package provides `Phoenix.LiveView` components!","ref":"Supabase.html#module-supabase-ui"},{"type":"function","title":"Supabase.init_client/3","doc":"Creates a new one off Supabase client, you you wanna a self managed client, that\nlevarages an [Agent][https://hexdocs.pm/elixir/Agent.html] instance that can\nstarted in your application supervision tree, check the `Supabase.Client` module docs.","ref":"Supabase.html#init_client/3"},{"type":"function","title":"Parameters - Supabase.init_client/3","doc":"- `base_url`: The unique Supabase URL which is supplied when you create a new project in your project dashboard.\n- `api_key`: The unique Supabase Key which is supplied when you create a new project in your project dashboard.\n- `options`: Additional options to configure the client behaviour, check `Supabase.Client.options()` typespec to check all available options.","ref":"Supabase.html#init_client/3-parameters"},{"type":"function","title":"Examples - Supabase.init_client/3","doc":"iex> Supabase.init_client(\"https:// \", \" \")\n    iex> {:ok, %Supabase.Client{}}\n\n    iex> Supabase.init_client(\"https:// \", \" \",\n      db: [schema: \"another\"],\n      auth: [flow_type: :pkce],\n      global: [headers: %{\"custom-header\" => \"custom-value\"}]\n    )\n    iex> {:ok, %Supabase.Client{}}","ref":"Supabase.html#init_client/3-examples"},{"type":"function","title":"Supabase.init_client!/3","doc":"Same as `Supabase.init_client/3` but raises if any errors occurs while\nparsing the client options.","ref":"Supabase.html#init_client!/3"},{"type":"type","title":"Supabase.result/1","doc":"Helper typespec to define general success and error returns","ref":"Supabase.html#t:result/1"},{"type":"type","title":"Supabase.service/0","doc":"The available Supabase services to interact with","ref":"Supabase.html#t:service/0"},{"type":"module","title":"Supabase.Client","doc":"A client for interacting with Supabase. This module is responsible for\nmanaging the connection options for your Supabase project.","ref":"Supabase.Client.html"},{"type":"module","title":"Usage - Supabase.Client","doc":"Generally, you can start a client by calling `Supabase.init_client/3`:\n\n    iex> base_url = \"https:// .supabase.io\"\n    iex> api_key = \" \"\n    iex> Supabase.init_client(base_url, api_key, %{})\n    {:ok, %Supabase.Client{}}\n\n> That way of initialisation is useful when you want to manage the client state by yourself or create one off clients.\n\nHowever, starting a client directly means you have to manage the client state by yourself. To make it easier, you can use the `Supabase.Client` module to manage the connection options for you, which we call a \"self managed client\".\n\nTo achieve this you can use the `Supabase.Client` module in your module:\n\n    defmodule MyApp.Supabase.Client do\n      use Supabase.Client, otp_app: :my_app\n    end\n\nThis will automatically start an [Agent](https://hexdocs.pm/elixir/Agent.html) process to manage the state for you. But for that to work, you need to configure your Supabase client options in your application configuration, either in compile-time (`config.exs`) or runtime (`runtime.exs`):\n\n    # config/runtime.exs or config/config.exs\n\n    config :my_app, MyApp.Supabase.Client,\n      base_url: \"https:// .supabase.co\",\n      api_key: \" \",\n      # any additional options\n      access_token: \" \",\n      db: [schema: \"another\"],\n      auth: [debug: true] # optional\n\nAnother alternative would be to configure your Supabase Client in code, while starting your application:\n\n    defmodule MyApp.Application do\n      use Application\n\n      def start(_type, _args) do\n        children = [\n          {MyApp.Supabase.Client, [\n            base_url: \"https:// .supabase.co\",\n            api_key: \" \"\n          ]}\n        ]\n\n        opts = [strategy: :one_for_one, name: MyApp.Supabase.Client.Supervisor]\n        Supervisor.start_link(children, opts)\n      end\n    end\n\nFor more information on how to configure your Supabase Client with additional options, please refer to the `Supabase.Client.t()` typespec.","ref":"Supabase.Client.html#module-usage"},{"type":"module","title":"Examples - Supabase.Client","doc":"%Supabase.Client{\n      base_url: \"https:// .supabase.io\",\n      api_key: \" \",\n      access_token: \" \",\n      db: %Supabase.Client.Db{\n        schema: \"public\"\n      },\n      global: %Supabase.Client.Global{\n        headers: %{}\n      },\n      auth: %Supabase.Client.Auth{\n        auto_refresh_token: true,\n        debug: false,\n        detect_session_in_url: true,\n        flow_type: :implicit,\n        persist_session: true,\n        storage_key: \"sb- -auth-token\"\n      }\n    }","ref":"Supabase.Client.html#module-examples"},{"type":"function","title":"Supabase.Client.changeset/1","doc":"","ref":"Supabase.Client.html#changeset/1"},{"type":"type","title":"Supabase.Client.options/0","doc":"The type for the available additional options that can be passed\nto `Supabase.init_client/3` to configure the Supabase client.\n\nNote that these options can be passed to `Supabase.init_client/3` as `Enumerable`, which means it can be either a `Keyword.t()` or a `Map.t()`, but internally it will be passed as a map.","ref":"Supabase.Client.html#t:options/0"},{"type":"type","title":"Supabase.Client.t/0","doc":"The type of the `Supabase.Client` that will be returned from `Supabase.init_client/3`.","ref":"Supabase.Client.html#t:t/0"},{"type":"type","title":"Source - Supabase.Client.t/0","doc":"https://supabase.com/docs/reference/javascript/initializing","ref":"Supabase.Client.html#t:t/0-source"},{"type":"function","title":"Supabase.Client.update_access_token/2","doc":"Helper function to swap the current acccess token being used in\nthe Supabase client instance.\n\nNote that this functions shoudln't be used directly if you are using a\nself managed client (aka started it into your supervision tree as the `Supabase.Client` moduledoc says), since it will return the updated client but it **won't**\nupdate the inner client in the `Agent` process.\n\nTo update the access token for a self managed client, you can use the `set_auth/2` function that is generated when you configure your client module.\n\nIf you're managing your own Supabase client state (aka one off clients) you can\nuse this helper function.","ref":"Supabase.Client.html#update_access_token/2"},{"type":"module","title":"Supabase.Client.Auth","doc":"Auth configuration schema. This schema is used to configure the auth\noptions. This schema is embedded in the `Supabase.Client` schema.","ref":"Supabase.Client.Auth.html"},{"type":"module","title":"Fields - Supabase.Client.Auth","doc":"- `:auto_refresh_token` - Automatically refresh the token when it expires. Defaults to `true`.\n- `:debug` - Enable debug mode. Defaults to `false`.\n- `:detect_session_in_url` - Detect session in URL. Defaults to `true`.\n- `:flow_type` - Authentication flow type. Defaults to `\"implicit\"`.\n- `:persist_session` - Persist session. Defaults to `true`.\n- `:storage` - Storage type.\n- `:storage_key` - Storage key. Default to `\"sb-$host-auth-token\"` where $host is the hostname of your Supabase URL.\n\nFor more information about the auth options, see the documentation for\nthe [client](https://supabase.com/docs/reference/javascript/initializing) and\n[auth guides](https://supabase.com/docs/guides/auth)","ref":"Supabase.Client.Auth.html#module-fields"},{"type":"function","title":"Supabase.Client.Auth.changeset/2","doc":"","ref":"Supabase.Client.Auth.html#changeset/2"},{"type":"type","title":"Supabase.Client.Auth.params/0","doc":"","ref":"Supabase.Client.Auth.html#t:params/0"},{"type":"type","title":"Supabase.Client.Auth.t/0","doc":"","ref":"Supabase.Client.Auth.html#t:t/0"},{"type":"behaviour","title":"Supabase.Client.Behaviour","doc":"The behaviour for the Supabase Client. This behaviour is used to define the API for a Supabase Client.\n\nIf you're implementing a [Self Managed Client](https://github.com/zoedsoupe/supabase-ex?tab=readme-ov-file#self-managed-clients) as the [Supabase.Client](https://hexdocs.pm/supabase_potion/Supabase.Client.html), this behaviour is already implemented for you.\n\nIf you're implementing a [One Off Client](https://github.com/zoedsoupe/supabase-ex?tab=readme-ov-file#one-off-clients) as the [Supabase.Client](https://hexdocs.pm/supabase_potion/Supabase.Client.html), you need to implement this behaviour in case you want to use the integration with [Supabase.GoTrue](https://hexdocs.pm/supabase_gotrue/readme.html) for [Plug](https://hexdocs.pm/plug) based application or [Phoenix.LiveView](https://hexdocs.pm/phoenix_live_view) applications.","ref":"Supabase.Client.Behaviour.html"},{"type":"callback","title":"Supabase.Client.Behaviour.get_client/0","doc":"","ref":"Supabase.Client.Behaviour.html#c:get_client/0"},{"type":"callback","title":"Supabase.Client.Behaviour.get_client/1","doc":"","ref":"Supabase.Client.Behaviour.html#c:get_client/1"},{"type":"callback","title":"Supabase.Client.Behaviour.init/0","doc":"","ref":"Supabase.Client.Behaviour.html#c:init/0"},{"type":"callback","title":"Supabase.Client.Behaviour.set_auth/2","doc":"","ref":"Supabase.Client.Behaviour.html#c:set_auth/2"},{"type":"module","title":"Supabase.Client.Db","doc":"DB configuration schema. This schema is used to configure the database\noptions. This schema is embedded in the `Supabase.Client` schema.","ref":"Supabase.Client.Db.html"},{"type":"module","title":"Fields - Supabase.Client.Db","doc":"- `:schema` - The default schema to use. Defaults to `\"public\"`.\n\nFor more information about the database options, see the documentation for\nthe [client](https://supabase.com/docs/reference/javascript/initializing) and\n[database guides](https://supabase.com/docs/guides/database).","ref":"Supabase.Client.Db.html#module-fields"},{"type":"function","title":"Supabase.Client.Db.changeset/2","doc":"","ref":"Supabase.Client.Db.html#changeset/2"},{"type":"type","title":"Supabase.Client.Db.params/0","doc":"","ref":"Supabase.Client.Db.html#t:params/0"},{"type":"type","title":"Supabase.Client.Db.t/0","doc":"","ref":"Supabase.Client.Db.html#t:t/0"},{"type":"module","title":"Supabase.Client.Global","doc":"Global configuration schema. This schema is used to configure the global\noptions. This schema is embedded in the `Supabase.Client` schema.","ref":"Supabase.Client.Global.html"},{"type":"module","title":"Fields - Supabase.Client.Global","doc":"- `:headers` - The default headers to use in any Supabase request. Defaults to `%{}`.","ref":"Supabase.Client.Global.html#module-fields"},{"type":"function","title":"Supabase.Client.Global.changeset/2","doc":"","ref":"Supabase.Client.Global.html#changeset/2"},{"type":"type","title":"Supabase.Client.Global.params/0","doc":"","ref":"Supabase.Client.Global.html#t:params/0"},{"type":"type","title":"Supabase.Client.Global.t/0","doc":"","ref":"Supabase.Client.Global.html#t:t/0"},{"type":"behaviour","title":"Supabase.Error","doc":"Represents and centralizes error responses within the Supabase ecosystem.\n\nThe `Supabase.Error` struct is a unified way to handle error responses, \nproviding fields to represent key attributes of an error while remaining flexible \nenough to accommodate custom implementations.","ref":"Supabase.Error.html"},{"type":"behaviour","title":"Fields - Supabase.Error","doc":"- `code` (atom): A semantic representation of the error code, e.g., `:not_found` or `:unauthorized`.\n- `message` (String.t): A human-readable message describing the error.\n- `service` (Supabase.service()): The service from which the error originated (e.g., `:auth`, `:storage`).\n- `metadata` (map): Additional information to provide context about the error, \n  such as the request path, headers, or response body.","ref":"Supabase.Error.html#module-fields"},{"type":"behaviour","title":"Example - Supabase.Error","doc":"%Supabase.Error{\n      code: :not_found,\n      message: \"Resource Not Found\",\n      service: :storage,\n      metadata: %{\n        path: \"/api/resource\",\n        req_body: %{},\n        resp_body: \"Not found\",\n        headers: [{\"content-type\", \"application/json\"}]\n      }\n    }","ref":"Supabase.Error.html#module-example"},{"type":"behaviour","title":"Custom Error Handling - Supabase.Error","doc":"Libraries or users may define custom error parsers by implementing the \n`Supabase.Error` behaviour's `from/2` callback from the `Supabase.ErrorParser`\nprotocol.\nThis enables the transformation of ANY structure into meaningful errors \nspecific to their application domain.","ref":"Supabase.Error.html#module-custom-error-handling"},{"type":"callback","title":"Supabase.Error.from/2","doc":"Callback used on invoking the HTTP error parsed on a response (status >= 400)","ref":"Supabase.Error.html#c:from/2"},{"type":"function","title":"Supabase.Error.humanize_error_code/1","doc":"Helper to just transform an atom code into a more human-friendly string","ref":"Supabase.Error.html#humanize_error_code/1"},{"type":"function","title":"Supabase.Error.make_default_http_metadata/1","doc":"Helper function to construct the metadata fields for when building\nan error from a HTTP response, based into the \"context\", aka `Supabase.Request`.","ref":"Supabase.Error.html#make_default_http_metadata/1"},{"type":"function","title":"Supabase.Error.new/1","doc":"Creates a new `Supabase.Error` struct based on informed options","ref":"Supabase.Error.html#new/1"},{"type":"type","title":"Supabase.Error.t/0","doc":"","ref":"Supabase.Error.html#t:t/0"},{"type":"module","title":"Supabase.Fetcher","doc":"`Supabase.Fetcher` is a comprehensive HTTP client designed to interface seamlessly with Supabase services. This module acts as the backbone for making HTTP requests, streaming data, uploading files, and managing request/response lifecycles within the Supabase ecosystem.","ref":"Supabase.Fetcher.html"},{"type":"module","title":"Key Features - Supabase.Fetcher","doc":"- **Request Composition**: Build requests with method, headers, body, and query parameters using a composable builder pattern via `Supabase.Fetcher.Request`.\n- **Streaming Support**: Stream large responses efficiently using `Finch.stream/5`, reducing memory usage for large payloads.\n- **Error Management**: Centralized error handling through `Supabase.ErrorParser`, supporting structured and semantic error reporting.","ref":"Supabase.Fetcher.html#module-key-features"},{"type":"module","title":"Key Components - Supabase.Fetcher","doc":"","ref":"Supabase.Fetcher.html#module-key-components"},{"type":"module","title":"HTTP Clients - Supabase.Fetcher","doc":"`Supabase.Fetcher` provides a `Supabase.Fetcher.Adapter` behaviour that defines\nthe interface to implement custom HTTP clients backends (e.g `Finch`, `Req`, `:httpc`).\n\nThat way is possible to use the same API defined on `Supabase.Fetcher` and customize\nhow make the actual HTTP request. The default implementation uses `Supabase.Fetcher.Adapter.Finch`.\n\nYou can customize the HTTP client used in `Supabase.Fetcher` with the `Supabase.Fetcher.Request.with_http_client/2` function while building your request:\n\n```elixir\nfetcher =\n  Supabase.Fetcher.Request.new(client)\n  |> Supabase.Fetcher.Request.with_http_client(Supabase.Fetcher.Adapter.Httpc)\n```\n\n`supabase_potion` would ideally provide multiple client implementations but you can\nsafely extend to your own preference using the aforementioned behaviour, something like:\n\n```elixir\ndefmodule MyHTTPClient do\n  @moduledoc \"My custom HTTP client to be used as backend for `Supabase.Fetcher`\"\n\n  @behaviour Supabase.Fetcher.Adapter\n\n  @impl true\n  def request(%Supabase.Fetcher.Request{}), do: # ...\n\n  @impl true\n  # optional, if the client support async requests\n  def request_async(%Supabase.Fetcher.Request{}), do: # ...\n\n  @impl true\n  # optional, if the client support response streaming\n  def stream(%Supabase.Fetcher.Request{}), do: # ...\n  def stream(%Supabase.Fetcher.Request{}, on_response), do: # ...\n\n  @impl true\n  # required to Storage upload to work\n  def upload(%Supabase.Fetcher.Request{}, file_path, options), do: # ...\nend\n```","ref":"Supabase.Fetcher.html#module-http-clients"},{"type":"module","title":"Decoders and Parsers - Supabase.Fetcher","doc":"- **Body Decoder**: Custom modules implementing the `Supabase.Fetcher.BodyDecoder` behaviour can decode response bodies into application-specific formats.\n- **Error Parser**: Handle service-specific errors using `Supabase.Error` implementations, ensuring consistent error reporting across services.","ref":"Supabase.Fetcher.html#module-decoders-and-parsers"},{"type":"module","title":"Streaming - Supabase.Fetcher","doc":"- `stream/1` and `stream/2` support fine-grained control over streamed responses, allowing consumers to process data incrementally while retaining access to status and headers.","ref":"Supabase.Fetcher.html#module-streaming"},{"type":"module","title":"Upload Support - Supabase.Fetcher","doc":"Effortlessly upload binary files using the `upload/2` function, which manages content type, headers, and streaming.","ref":"Supabase.Fetcher.html#module-upload-support"},{"type":"module","title":"Example Usage - Supabase.Fetcher","doc":"","ref":"Supabase.Fetcher.html#module-example-usage"},{"type":"module","title":"Basic Request - Supabase.Fetcher","doc":"```elixir\n{:ok, %Supabase.Fetcher.Response{} = response} =\n  Supabase.Fetcher.Request.new(client)\n  |> Supabase.Fetcher.Request.with_auth_url(\"/token\")\n  |> Supabase.Fetcher.Request.with_method(:post)\n  |> Supabase.Fetcher.Request.with_body(%{username: \"test\", password: \"test\"})\n  |> Supabase.Fetcher.request()\n```","ref":"Supabase.Fetcher.html#module-basic-request"},{"type":"module","title":"Streaming - Supabase.Fetcher","doc":"","ref":"Supabase.Fetcher.html#module-streaming"},{"type":"module","title":"Consume the whole stream - Supabase.Fetcher","doc":"```elixir\n{:ok, %Supabase.Fetcher.Response{body: <<...>>}} =\n  Supabase.Fetcher.Request.new(client)\n  |> Supabase.Fetcher.Request.with_storage_url(\"/large-file\")\n  |> Supabase.Fetcher.stream()\n```","ref":"Supabase.Fetcher.html#module-consume-the-whole-stream"},{"type":"module","title":"Fine-grained control over body stream - Supabase.Fetcher","doc":"```elixir\non_response = fn {status, headers, body} ->\n  try do\n    file = File.stream!(\"output.txt\", [:write, :utf8])\n\n    body\n    |> Stream.into(file)\n    |> Stream.run()\n\n    {:ok, %Supabase.Fetcher.Response{status: status, headers: headers}}\n  rescue\n    e in File.Error -> {:error, e.reason}\n  end\nend\n\n{:ok, %Supabase.Fetcher.Response{body: stream}} =\n  Supabase.Fetcher.Request.new(client)\n  |> Supabase.Fetcher.Request.with_storage_url(\"/large-file\")\n  |> Supabase.Fetcher.stream(on_response)\n```","ref":"Supabase.Fetcher.html#module-fine-grained-control-over-body-stream"},{"type":"module","title":"Custom Decoders and Error Parsers - Supabase.Fetcher","doc":"```elixir\n{:ok, %Supabase.Decoder{} = response} =\n  Supabase.Fetcher.Request.new(client)\n  |> Supabase.Fetcher.Request.with_functions_url(\"/execute\")\n  |> Supabase.Fetcher.Request.with_body_decoder(MyCustomDecoder)\n  |> Supabase.Fetcher.Request.with_error_parser(MyErrorParser)\n  |> Supabase.Fetcher.request()\n```","ref":"Supabase.Fetcher.html#module-custom-decoders-and-error-parsers"},{"type":"module","title":"Notes - Supabase.Fetcher","doc":"This module is designed to be extensible and reusable for all Supabase-related services. It abstracts away the low-level HTTP intricacies while providing the flexibility developers need to interact with Supabase services in Elixir applications.\n\nIn general, if you don't have specific needs, custom application formats or you aren't\nbuilding something new around `Supabase.Fetcher` you generally are safe using the default options if you only need to consume Supabase services as a client.","ref":"Supabase.Fetcher.html#module-notes"},{"type":"type","title":"Supabase.Fetcher.body/0","doc":"","ref":"Supabase.Fetcher.html#t:body/0"},{"type":"type","title":"Supabase.Fetcher.headers/0","doc":"","ref":"Supabase.Fetcher.html#t:headers/0"},{"type":"function","title":"Supabase.Fetcher.merge_headers/2","doc":"Merge two collections of headers as an `Enumberable.t()`, avoiding duplicates and removing nullable headers\n- aka `nil` values.\n\nNote that this function is **right-associative** in terms of header priority,\nthis means that any duplicate new header that is passed to this function\nwill **overwrite** the last definition, take caution with it.","ref":"Supabase.Fetcher.html#merge_headers/2"},{"type":"type","title":"Supabase.Fetcher.method/0","doc":"","ref":"Supabase.Fetcher.html#t:method/0"},{"type":"type","title":"Supabase.Fetcher.query/0","doc":"","ref":"Supabase.Fetcher.html#t:query/0"},{"type":"function","title":"Supabase.Fetcher.request/2","doc":"Executes the current request builder, synchronously and returns the response.","ref":"Supabase.Fetcher.html#request/2"},{"type":"function","title":"Supabase.Fetcher.request_async/2","doc":"Executes the current request builder, asynchronously and returns the response.\nNote that this function does not **stream** the request, although it can use\na stream to consume chunks, as you can see an example in `Supabase.Fetcher.Adapter.Finch`.\n\nWhat happens here is that the request is done on a separate process, and the response\nis sent via message passing, in chunks, so no all HTTP client support async requests.\n\nAlso, this function provides a higher-level API to just trigger the request dispatch\nand return a result, so the use experience looks like the sync version `request/2`.\n\nIf you wanna **stream** a HTTP request, then you should go with `stream/2` or `stream/3`.\n\nAnd if you wanna **upload** a binary/file, streaming it, then you should go with `upload/3`.","ref":"Supabase.Fetcher.html#request_async/2"},{"type":"type","title":"Supabase.Fetcher.response/0","doc":"Generic typespec to define possible response values, adapt to each client","ref":"Supabase.Fetcher.html#t:response/0"},{"type":"type","title":"Supabase.Fetcher.status/0","doc":"","ref":"Supabase.Fetcher.html#t:status/0"},{"type":"function","title":"Supabase.Fetcher.stream/3","doc":"Makes a HTTP request from the request builder and\nstream back the response. Good to stream large files downloads, as it what\n`Supabase.Storage` does.\n\nThe `Supabase.Fetcher.stream/2` consumes the whole response stream and returns, in case of success, `{:ok, %Supabase.Fetcher.Response{}}`, however you can have a more fine-grained control of the stream using `Supabase.Fetcher.stream/3`.\n\nThe `stream/2` behaviour look likes `request/2` and `request_async/2` since it feels\nlike a sync request where you dispatch and receive a parsed result.\n\nFor have more control of the response chunks, you can pass a 1 arity function, with that the response stream will be\n**partially** consumed to get the response status and headers, but the body will\nremain as a stream, then it will invoke the `on_response` function that you passed\nwith `{status, headers, stream}` as argument, then you should return `Supabase.Fetcher.Response` in case of success or `Supabase.Error` in case of error.","ref":"Supabase.Fetcher.html#stream/3"},{"type":"function","title":"Supabase.Fetcher.upload/3","doc":"Upload a binary file based into the current request builder.","ref":"Supabase.Fetcher.html#upload/3"},{"type":"type","title":"Supabase.Fetcher.url/0","doc":"","ref":"Supabase.Fetcher.html#t:url/0"},{"type":"behaviour","title":"Supabase.Fetcher.Adapter","doc":"Behaviour that defines the interface to implement different HTTP clients\nas backends for the `Supabase.Fetcher` request builder.","ref":"Supabase.Fetcher.Adapter.html"},{"type":"function","title":"Supabase.Fetcher.Adapter.not_implemented_error/3","doc":"","ref":"Supabase.Fetcher.Adapter.html#not_implemented_error/3"},{"type":"callback","title":"Supabase.Fetcher.Adapter.request/2","doc":"","ref":"Supabase.Fetcher.Adapter.html#c:request/2"},{"type":"callback","title":"Supabase.Fetcher.Adapter.request_async/2","doc":"","ref":"Supabase.Fetcher.Adapter.html#c:request_async/2"},{"type":"type","title":"Supabase.Fetcher.Adapter.request_opts/0","doc":"","ref":"Supabase.Fetcher.Adapter.html#t:request_opts/0"},{"type":"type","title":"Supabase.Fetcher.Adapter.response/0","doc":"","ref":"Supabase.Fetcher.Adapter.html#t:response/0"},{"type":"callback","title":"Supabase.Fetcher.Adapter.stream/2","doc":"","ref":"Supabase.Fetcher.Adapter.html#c:stream/2"},{"type":"callback","title":"Supabase.Fetcher.Adapter.stream/3","doc":"","ref":"Supabase.Fetcher.Adapter.html#c:stream/3"},{"type":"callback","title":"Supabase.Fetcher.Adapter.upload/3","doc":"","ref":"Supabase.Fetcher.Adapter.html#c:upload/3"},{"type":"module","title":"Supabase.Fetcher.Adapter.Finch","doc":"HTTP Client backend implementation for `Supabase.Fetcher` using Finch","ref":"Supabase.Fetcher.Adapter.Finch.html"},{"type":"behaviour","title":"Supabase.Fetcher.Behaviour","doc":"Defines Supabase HTTP Clients callbacks","ref":"Supabase.Fetcher.Behaviour.html"},{"type":"callback","title":"Supabase.Fetcher.Behaviour.request/1","doc":"","ref":"Supabase.Fetcher.Behaviour.html#c:request/1"},{"type":"callback","title":"Supabase.Fetcher.Behaviour.request_async/1","doc":"","ref":"Supabase.Fetcher.Behaviour.html#c:request_async/1"},{"type":"callback","title":"Supabase.Fetcher.Behaviour.stream/1","doc":"","ref":"Supabase.Fetcher.Behaviour.html#c:stream/1"},{"type":"callback","title":"Supabase.Fetcher.Behaviour.stream/2","doc":"","ref":"Supabase.Fetcher.Behaviour.html#c:stream/2"},{"type":"callback","title":"Supabase.Fetcher.Behaviour.upload/2","doc":"","ref":"Supabase.Fetcher.Behaviour.html#c:upload/2"},{"type":"behaviour","title":"Supabase.Fetcher.BodyDecoder","doc":"Behaviour to define custom body decoders to a HTTP response\n\nTO define a custom body decoder you need to implement this behaviour and\nregister it into the request builder that will use it, for example, for a custom\nJSONDecoder:\n\n    defmodule MyJSONDecoder do\n      @behaviour Supabase.Fetcher.BodyDecoder\n\n      @impl true\n      def decode(%Finch.Response{} = resp, opts) do\n      end\n    end\n\nWhen registering custom body decoder, you can pass it custom options as keyword list\nso they'll be available as the second parameter of the `decode/2` behaviour function.","ref":"Supabase.Fetcher.BodyDecoder.html"},{"type":"callback","title":"Supabase.Fetcher.BodyDecoder.decode/2","doc":"","ref":"Supabase.Fetcher.BodyDecoder.html#c:decode/2"},{"type":"module","title":"Supabase.Fetcher.JSONDecoder","doc":"The default body decoder to HTTP responses","ref":"Supabase.Fetcher.JSONDecoder.html"},{"type":"function","title":"Supabase.Fetcher.JSONDecoder.decode/2","doc":"Tries to decode the response body as JSON","ref":"Supabase.Fetcher.JSONDecoder.html#decode/2"},{"type":"module","title":"Supabase.Fetcher.Request","doc":"`Supabase.Fetcher.Request` is a structure to handle HTTP request builder designed to interface seamlessly with Supabase services.","ref":"Supabase.Fetcher.Request.html"},{"type":"module","title":"Key Features - Supabase.Fetcher.Request","doc":"- **Request Composition**: Build requests with method, headers, body, and query parameters using a composable builder pattern.\n- **Service-Specific Integrations**: Automatically derive URLs for Supabase services like `auth`, `functions`, `storage`, `realtime`, and `database`.\n- **Customizable Response Handling**: Attach decoders and error parsers tailored to specific service requirements.\n- **Error Management**: Centralized error handling through `Supabase.ErrorParser`, supporting structured and semantic error reporting.","ref":"Supabase.Fetcher.Request.html#module-key-features"},{"type":"module","title":"Key Components - Supabase.Fetcher.Request","doc":"","ref":"Supabase.Fetcher.Request.html#module-key-components"},{"type":"module","title":"Request Builder API - Supabase.Fetcher.Request","doc":"The `Supabase.Fetcher.Request` provides a composable API for constructing HTTP requests. Each step updates the request builder state:\n\n- `with_ _url/2`: Appends the path to a service-specific base URL, available services can be consulted on `Supabase.services()` typespec.\n- `with_method/2`: Sets the HTTP method (`:get`, `:post`, etc.).\n- `with_headers/2`: Appends or overrides headers.\n- `with_body/2`: Sets the request body, supporting JSON, iodata, or streams.\n- `with_query/2`: Adds query parameters.\n- `with_body_decoder/3`: Registers a custom body decoder to be hooked into the response, defaults to `Supabase.Fetcher.JSONDecoder`.\n- `with_error_parser/2`: Registers a custom error parser to be hooked into the response, defaults to `Supabase.ErrorParser`.","ref":"Supabase.Fetcher.Request.html#module-request-builder-api"},{"type":"module","title":"Custom HTTP Clients - Supabase.Fetcher.Request","doc":"`Supabase.Fetcher.Request` depends on a  `Supabase.Fetcher.Adapter` implementation to dispatch HTTP requests, check `Supabase.Fetcher` module documentation for more info.","ref":"Supabase.Fetcher.Request.html#module-custom-http-clients"},{"type":"module","title":"Decoders and Parsers - Supabase.Fetcher.Request","doc":"- **Body Decoder**: Custom modules implementing the `Supabase.Fetcher.BodyDecoder` behaviour can decode response bodies into application-specific formats.\n- **Error Parser**: Handle service-specific errors using `Supabase.Error` implementations, ensuring consistent error reporting across services.","ref":"Supabase.Fetcher.Request.html#module-decoders-and-parsers"},{"type":"module","title":"Example Usage - Supabase.Fetcher.Request","doc":"","ref":"Supabase.Fetcher.Request.html#module-example-usage"},{"type":"module","title":"Basic Request - Supabase.Fetcher.Request","doc":"```elixir\n{:ok, response} =\n  Supabase.Fetcher.new(client)\n  |> Supabase.Fetcher.with_auth_url(\"/token\")\n  |> Supabase.Fetcher.with_method(:post)\n  |> Supabase.Fetcher.with_body(%{username: \"test\", password: \"test\"})\n  |> Supabase.Fetcher.request()\n```","ref":"Supabase.Fetcher.Request.html#module-basic-request"},{"type":"module","title":"Custom Decoders and Error Parsers - Supabase.Fetcher.Request","doc":"```elixir\n{:ok, response} =\n  Supabase.Fetcher.new(client)\n  |> Supabase.Fetcher.with_functions_url(\"/execute\")\n  |> Supabase.Fetcher.with_body_decoder(MyCustomDecoder)\n  |> Supabase.Fetcher.with_error_parser(MyErrorParser)\n  |> Supabase.Fetcher.request()\n```","ref":"Supabase.Fetcher.Request.html#module-custom-decoders-and-error-parsers"},{"type":"module","title":"Notes - Supabase.Fetcher.Request","doc":"This module is designed to be extensible and reusable for all Supabase-related services. It abstracts away the low-level HTTP intricacies while providing the flexibility developers need to interact with Supabase services in Elixir applications.","ref":"Supabase.Fetcher.Request.html#module-notes"},{"type":"function","title":"Supabase.Fetcher.Request.get_header/3","doc":"Tries to find and return the value for a request headers, given it name, if it doesn't\nexistis, it returns the default value informed or `nil`.\n\nDo not confuse with `Supabase.Response.get_header/2`.","ref":"Supabase.Fetcher.Request.html#get_header/3"},{"type":"function","title":"Supabase.Fetcher.Request.get_query_param/3","doc":"Tries to find and return the value for a query param, given it name, if it doesn't\nexistis, it returns the default value informed or `nil`.","ref":"Supabase.Fetcher.Request.html#get_query_param/3"},{"type":"function","title":"Supabase.Fetcher.Request.merge_query_param/4","doc":"Merges an existing query param value with a new one, prepending the new value\nwith the existing one. If no current value exists for the param, this function\nwill behave the same as `with_query/2`.","ref":"Supabase.Fetcher.Request.html#merge_query_param/4"},{"type":"function","title":"Supabase.Fetcher.Request.merge_req_header/4","doc":"Merges an existing request header value with a new one, prepending the new value\nwith the existing one. If no current value exists for the header, this function\nwill behave the same as `with_headers/2`.","ref":"Supabase.Fetcher.Request.html#merge_req_header/4"},{"type":"function","title":"Supabase.Fetcher.Request.new/2","doc":"Initialise the `Supabase.Fetcher` struct, accumulating the\nclient global headers and the client itself, so the request can be\neasily composed using the `with_` functions of this module.","ref":"Supabase.Fetcher.Request.html#new/2"},{"type":"type","title":"Supabase.Fetcher.Request.options/0","doc":"","ref":"Supabase.Fetcher.Request.html#t:options/0"},{"type":"type","title":"Supabase.Fetcher.Request.t/0","doc":"","ref":"Supabase.Fetcher.Request.html#t:t/0"},{"type":"function","title":"Supabase.Fetcher.Request.with_auth_url/2","doc":"Applies the auth base url from the client and appends the\ninformed path to the url. Note that this function will overwrite\nthe `url` field each time of call.","ref":"Supabase.Fetcher.Request.html#with_auth_url/2"},{"type":"function","title":"Supabase.Fetcher.Request.with_body/2","doc":"Defines the request body to be sent, it can be a map, that will be encoded\nwith `Jason.encode_to_iodata!/1`, any `iodata` or a stream body in the pattern of `{:stream, Enumerable.t}`, although you will problably prefer to use the `upload/2`\nfunction of this module to hadle body stream since it will handle file management, content headers and so on.","ref":"Supabase.Fetcher.Request.html#with_body/2"},{"type":"function","title":"Supabase.Fetcher.Request.with_body_decoder/3","doc":"Attaches a custom body decoder to be called after a successfull response.\nThe body decoder should implement the `Supabase.Fetcher.BodyDecoder` behaviour, and it default\nto the `Supabase.Fetcher.JSONDecoder`, or it can be a 2-arity function that will follow the `Supabase.Fetcher.BodyDecoder.decode` callback interface.\n\nYou can pass `nil` as the decoder to avoid body decoding, if you need the raw body.","ref":"Supabase.Fetcher.Request.html#with_body_decoder/3"},{"type":"function","title":"Supabase.Fetcher.Request.with_database_url/2","doc":"Applies the database base url from the client and appends the\ninformed path to the url. Note that this function will overwrite\nthe `url` field each time of call.","ref":"Supabase.Fetcher.Request.html#with_database_url/2"},{"type":"function","title":"Supabase.Fetcher.Request.with_error_parser/2","doc":"Attaches a custom error parser to be called after a \"successfull\" response.\nThe error parser should implement the `Supabase.Error` behaviour, and it default\nto the `Supabase.HTTPErrorParser`.\n\n\"successful\" response means that the fetcher actually got a HTTP response from\nthe server, so if the HTTP status is >= 400, so this error parser will be invoked.\n\nCheck `Supabase.HTTPErrorParser` for an example of implementation.","ref":"Supabase.Fetcher.Request.html#with_error_parser/2"},{"type":"function","title":"Supabase.Fetcher.Request.with_functions_url/2","doc":"Applies the functions base url from the client and appends the\ninformed path to the url. Note that this function will overwrite\nthe `url` field each time of call.","ref":"Supabase.Fetcher.Request.html#with_functions_url/2"},{"type":"function","title":"Supabase.Fetcher.Request.with_headers/2","doc":"Append headers to the current request builder, the headers needs to be an\n`Enumerable.t()` and will be merged via `merge_headers/2`, which means that\nthis function can be called multiple times **without** overwriting the existing\nheaders definitions.","ref":"Supabase.Fetcher.Request.html#with_headers/2"},{"type":"function","title":"Supabase.Fetcher.Request.with_http_client/2","doc":"Registers a custom HTTP client backend to be used by `Supabase.Fetcher` while\ndispatching the request. The default one is `Supabase.Fetcher.Adapter.Finch`","ref":"Supabase.Fetcher.Request.html#with_http_client/2"},{"type":"function","title":"Supabase.Fetcher.Request.with_method/2","doc":"Define the method of the request, default to `:get`, the available options\nare the same of `Finch.Request.method()` and note that this function\nwill overwrite the `method` attribute each time is called.","ref":"Supabase.Fetcher.Request.html#with_method/2"},{"type":"function","title":"Supabase.Fetcher.Request.with_query/2","doc":"Append query params to the current request builder, it receives an `Enumerable.t()`\nand accumulates it into the current request. This function behaves the same as\n`with_headers/2`, so it is **rigt-associative**, meaning that duplicate keys\ninformed will overwrite the last value.\n\nFinally, before the request is sent, the query will be encoded with `URI.encode_query/1`","ref":"Supabase.Fetcher.Request.html#with_query/2"},{"type":"function","title":"Supabase.Fetcher.Request.with_realtime_url/2","doc":"Applies the realtime base url from the client and appends the\ninformed path to the url. Note that this function will overwrite\nthe `url` field each time of call.","ref":"Supabase.Fetcher.Request.html#with_realtime_url/2"},{"type":"function","title":"Supabase.Fetcher.Request.with_storage_url/2","doc":"Applies the storage base url from the client and appends the\ninformed path to the url. Note that this function will overwrite\nthe `url` field each time of call.","ref":"Supabase.Fetcher.Request.html#with_storage_url/2"},{"type":"module","title":"Supabase.Fetcher.Response","doc":"Defines a common structure to operate on HTTP responses from different\nHTTP clients backends and also defines helper functions to operate this\nsame structure","ref":"Supabase.Fetcher.Response.html"},{"type":"function","title":"Supabase.Fetcher.Response.decode_body/3","doc":"Helper function to directly decode the body using a `Supabase.Fetcher.BodyDecoder`","ref":"Supabase.Fetcher.Response.html#decode_body/3"},{"type":"function","title":"Supabase.Fetcher.Response.get_header/2","doc":"Helper function to get a specific header value from a response.","ref":"Supabase.Fetcher.Response.html#get_header/2"},{"type":"function","title":"Supabase.Fetcher.Response.get_header/3","doc":"","ref":"Supabase.Fetcher.Response.html#get_header/3"},{"type":"type","title":"Supabase.Fetcher.Response.t/0","doc":"","ref":"Supabase.Fetcher.Response.html#t:t/0"},{"type":"protocol","title":"Supabase.Fetcher.ResponseAdapter","doc":"","ref":"Supabase.Fetcher.ResponseAdapter.html"},{"type":"function","title":"Supabase.Fetcher.ResponseAdapter.from/1","doc":"Normalizes a client-specific response into a Supabase.Fetcher.Response struct.","ref":"Supabase.Fetcher.ResponseAdapter.html#from/1"},{"type":"type","title":"Supabase.Fetcher.ResponseAdapter.t/0","doc":"All the types that implement this protocol.","ref":"Supabase.Fetcher.ResponseAdapter.html#t:t/0"},{"type":"module","title":"Supabase.HTTPErrorParser","doc":"The default error parser in case no one is provided via `Supabase.Fetcher.Request.with_error_parser/2`.\n\nError parsers should be implement firstly by adjacent services libraries, to\nhandle service-specific error like for authentication or storage, although\na final user could easily attach their own custom error parser.\n\nThe default error parser define the `code` and `message` fields based into\nthe HTTP Status.\n\nThe default `metadata` format is:\n\n    %{\n      path: \"The URL path appended to the base_url in request\",\n      req_body: \"The request body, encoded as iodata or binary\",\n      resp_body: \"The response body as it is\",\n      # headers is a list of tuples (String.t, String.t)\n      # the `authorization` header is removed from it\n      headers: []\n    }\n\nAll other fields are filled with the `Supabase.Request` struct as context,\nif available.","ref":"Supabase.HTTPErrorParser.html"},{"type":"function","title":"Supabase.HTTPErrorParser.from/2","doc":"","ref":"Supabase.HTTPErrorParser.html#from/2"},{"type":"exception","title":"Supabase.MissingSupabaseConfig","doc":"","ref":"Supabase.MissingSupabaseConfig.html"},{"type":"extras","title":"Supabase Potion","doc":"# Supabase Potion\n\nWhere the magic starts!\n\n> [!WARNING]\n> This project is still in high development, expect breaking changes and unexpected behaviour.","ref":"readme.html"},{"type":"extras","title":"Getting Started - Supabase Potion","doc":"","ref":"readme.html#getting-started"},{"type":"extras","title":"Examples - Supabase Potion","doc":"This repository contains a few examples with sample apps to help you get started and showcase each usage of the client implementations:\n\n#### Gotrue/Auth examples\n\nTODO\n\n<!--\n- [Plug based auth](https://github.com/zoedsoupe/supabase-ex/tree/main/examples/auth/plug)\n- [Phoenix LiveView based auth](https://github.com/zoedsoupe/supabase-ex/tree/main/examples/auth/phoenix_live_view)\n- [User management](https://github.com/zoedsoupe/supabase-ex/tree/main/examples/auth/user_management)\n-->\n\n#### Storage examples\n\nTODO\n\n<!--\n- [Plug based upload](https://github.com/zoedsoupe/supabase-ex/tree/main/examples/storage/plug)\n- [Phoenix LiveView upload](https://github.com/zoedsoupe/supabase-ex/tree/main/examples/storage/phoenix_live_view)\n-->","ref":"readme.html#examples"},{"type":"extras","title":"Installation - Supabase Potion","doc":"To install the base SDK:\n\n```elixir\ndef deps do\n  [\n    {:supabase_potion, \"~> 0.5\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"General usage - Supabase Potion","doc":"This library per si is the base foundation to user Supabase services from Elixir, so to integrate with specific services you need to add each client library you want to use.\n\nAvailable client services are:\n- [PostgREST](https://github.com/supabase-community/postgres-ex)\n- [Storage](https://github.com/supabase-community/storage-ex)\n- [Auth/GoTrue](https://github.com/supabase-community/auth-ex)\n\nSo if you wanna use the Storage and Auth/GoTrue services, your `mix.exs` should look like that:\n\n```elixir\ndef deps do\n  [\n    {:supabase_potion, \"~> 0.5\"}, # base SDK\n    {:supabase_storage, \"~> 0.3\"}, # storage integration\n    {:supabase_gotrue, \"~> 0.3\"}, # auth integration\n    {:supabase_postgrest, \"~> 0.2\"}, # postgrest integration\n  ]\nend\n```","ref":"readme.html#general-usage"},{"type":"extras","title":"Clients - Supabase Potion","doc":"A `Supabase.Client` holds general information about Supabase, that can be used to intereact with any of the children integrations, for example: `Supabase.Storage` or `Supabase.UI`.\n\n`Supabase.Client` is defined as:\n\n- `:base_url` - The base url of the Supabase API, it is usually in the form `https:// .supabase.io`.\n- `:api_key` - The API key used to authenticate requests to the Supabase API.\n- `:access_token` - Token with specific permissions to access the Supabase API, it is usually the same as the API key.\n- `:db` - default database options\n    - `:schema` - default schema to use, defaults to `\"public\"`\n- `:global` - global options config\n    - `:headers` - additional headers to use on each request\n- `:auth` - authentication options\n    - `:auto_refresh_token` - automatically refresh the token when it expires, defaults to `true`\n    - `:debug` - enable debug mode, defaults to `false`\n    - `:detect_session_in_url` - detect session in URL, defaults to `true`\n    - `:flow_type` - authentication flow type, defaults to `\"web\"`\n    - `:persist_session` - persist session, defaults to `true`\n    - `:storage_key` - storage key","ref":"readme.html#clients"},{"type":"extras","title":"Usage - Supabase Potion","doc":"There are two ways to create a `Supabase.Client`:\n1. one off clients\n2. self managed clients\n\n#### One off clients\n\nOne off clients are clients that are created and managed by your application. They are useful for quick interactions with the Supabase API.\n\n```elixir\niex> Supabase.init_client(\"https:// \", \" \")\niex> {:ok, %Supabase.Client{}}\n```\n\nAny additional config can be passed as the third argument as an [Enumerable](https://hexdocs.pm/elixir/Enumerable.html):\n\n```elixir\niex> Supabase.init_client(\"https:// \", \" \",\n  db: [schema: \"another\"],\n  auth: [flow_type: :pkce],\n  global: [headers: %{\"custom-header\" => \"custom-value\"}]\n)\niex> {:ok, %Supabase.Client{}}\n```\n\n> Note that one off clients are just raw elixir structs and therefore don't manage any state\n\nFor more information on the available options, see the [Supabase.Client](https://hexdocs.pm/supabase_potion/Supabase.Client.html) module documentation.\n\n> There's also a bang version of `Supabase.init_client/3` that will raise an error if the client can't be created.\n\nYou can also define a module that will centralize the client initialization:\n\n```elixir\ndefmodule MyApp.Supabase.Client do\n  @behaviour Supabase.Client.Behaviour\n\n  @impl true\n  def init do\n    # your client initialization\n    # you should return {:ok, client} or {:error, reason}\n    # you probably want to use `Supabase.init_client/3` here\n    # but get the base_url and api_key from anywhere you want\n  end\n\n  @impl true\n  def get_client do\n    # your client retrieval\n    # you should return the client\n    # the management of the client state is up to you\n  end\nend\n```\n\nFor self managed clients, check the [next section](#self-managed-clients).\n\n#### Self managed clients\n\nSelf managed clients are clients that are created and managed by a separate process on your application. They are useful for long running applications that need to interact with the Supabase API.\n\nIf you don't have experience with processes or is a Elixir begginner, you should take a deep look into the Elixir official getting started section about processes, concurrency and distribution before to proceed.\n- [Processes](https://hexdocs.pm/elixir/processes.html)\n- [Agent getting started](https://hexdocs.pm/elixir/agents.html)\n- [GenServer getting started](https://hexdocs.pm/elixir/genservers.html)\n- [Supervison trees getting started](https://hexdocs.pm/elixir/supervisor-and-application.html)\n\nSo, to define a self managed client, you need to define a module that will hold the client state and the client process as an [Agent](https://hexdocs.pm/elixir/Agent.html).\n\n```elixir\ndefmodule MyApp.Supabase.Client do\n  use Supabase.Client, otp_app: :my_app\nend\n```\n\nFor that to work, you also need to configure the client in your app configuration, it can be a compile-time config on `config.exs` or a runtime config in `runtime.exs`:\n\n```elixir\nimport Config\n\n# `:my_app` here is the same `otp_app` option you passed\nconfig :my_app, MyApp.Supabase.Client,\n  base_url: \"https:// \", # required\n  api_key: \" \", # required\n  access_token: \" \", # optional\n   # additional options\n  db: [schema: \"another\"],\n  auth: [flow_type: :implicit, debug: true],\n  global: [headers: %{\"custom-header\" => \"custom-value\"}]\n```\n\nThen, you can start the client process in your application supervision tree, generally in your `application.ex` module:\n\n```elixir\ndefmodule MyApp.Application do\n  use Application\n\n  def start(_type, _args) do\n    children = [\n      MyApp.Supabase.Client\n    ]\n\n    opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```\n\n> Of course, you can spawn as many clients you wanna, with different configurations if you need\n\nNow you can interact with the client process:\n\n```elixir\niex> {:ok, %Supabase.Client{} = client} = MyApp.Supabase.Client.get_client()\niex> Supabase.GoTrue.sign_in_with_password(client, email: \"\", password: \"\")\n```\n\nYou can also update the `access_token` for it:\n\n```elixir\niex> {:ok, %Supabase.Client{} = client} = MyApp.Supabase.Client.get_client()\niex> client.access_token == client.api_key\niex> :ok = MyApp.Supabase.Client.set_auth(\"new-access-token\")\niex> {:ok, %Supabase.Client{} = client} = MyApp.Supabase.Client.get_client()\niex> client.access_token == \"new-access-token\"\n```\n\nFor more examples on how to use the client, check clients implementations docs:\n- [Supabase.GoTrue](https://hexdocs.pm/supabase_gotrue)\n- [Supabase.Storage](https://hexdocs.pm/supabase_storage)\n- [Supabase.PostgREST](https://hexdocs.pm/supabase_postgrest)","ref":"readme.html#usage"},{"type":"extras","title":"How to find my Supabase base URL? - Supabase Potion","doc":"You can find your Supabase base URL in the Settings page of your project.\nFirstly select your project from the initial Dashboard.\nOn the left sidebar, click on the Settings icon, then select API.\nThe base URL is the first field on the page.","ref":"readme.html#how-to-find-my-supabase-base-url"},{"type":"extras","title":"How to find my Supabase API Key? - Supabase Potion","doc":"You can find your Supabase API key in the Settings page of your project.\nFirstly select your project from the initial Dashboard.\nOn the left sidebar, click on the Settings icon, then select API.\nThe API key is the second field on the page.\n\nThere two types of API keys, the public and the private. The last one\nbypass any Row Level Security (RLS) rules you have set up.\nSo you shouldn't use it in your frontend application.\n\nIf you don't know what RLS is, you can read more about it here:\nhttps://supabase.com/docs/guides/auth/row-level-security\n\nFor most cases you should prefer to use the public \"anon\" Key.","ref":"readme.html#how-to-find-my-supabase-api-key"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nAll notable changes to this project are documented in this file.\n\n## [0.6.0] - 2025-01-10","ref":"changelog.html"},{"type":"extras","title":"Added - Changelog","doc":"- Enhanced HTTP handling with support for custom headers, streaming, and centralized error management.\n- Improved test coverage and added dependency `mox` for mocking.\n- CI/CD pipeline improvements with caching for faster builds.","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- Resolved header merging issues and inconsistencies in JSON error handling.","ref":"changelog.html#fixed"},{"type":"extras","title":"Removed - Changelog","doc":"- Dropped `manage_clients` option; explicit OTP management required.","ref":"changelog.html#removed"},{"type":"extras","title":"Issues - Changelog","doc":"- Fixed \"[Fetcher] Extract error parsing to its own module\" [#23](https://github.com/supabase-community/supabase-ex/issues/23)\n- Fixed \"Unable to pass `auth` key inside options to `init_client`\" [#45](https://github.com/supabase-community/supabase-ex/issues/45)\n- Fixed \"Proposal to refactor and simplify the `Supabase.Fetcher` module\" [#51](https://github.com/supabase-community/supabase-ex/issues/51)\n- Fixed \"Invalid Unicode error during file uploads (affets `storage-ex`)\" [#52](https://github.com/supabase-community/supabase-ex/issues/52)\n\n---\n\n## [0.5.1] - 2024-09-21","ref":"changelog.html#issues"},{"type":"extras","title":"Added - Changelog","doc":"- Improved error handling for HTTP fetch operations.\n- Added optional retry policies for idempotent requests.","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- Resolved race conditions in streaming functionality.\n\n---\n\n## [0.5.0] - 2024-09-21","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- Support for direct file uploads to cloud storage.\n- Enhanced real-time subscription management.","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- Corrected WebSocket reconnection logic under high load.\n\n---\n\n## [0.4.1] - 2024-08-30","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Changelog","doc":"- Performance optimizations in JSON encoding and decoding.\n- Improved logging for debugging.","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Addressed memory leaks in connection pooling.\n\n---\n\n## [0.4.0] - 2024-08-30","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- Introduced WebSocket monitoring tools.\n- Support for encrypted token storage.\n\n---\n\n## [0.3.7] - 2024-05-14","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- Initial implementation of streaming API for large datasets.","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- Bug fixes in the pagination logic.\n\n---\n\n## [0.3.6] - 2024-04-28","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- Experimental support for Ecto integration.\n\n---\n\n## [0.3.5] - 2024-04-21","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- Addressed intermittent crashes when initializing connections.\n\n---\n\n## [0.3.4] - 2024-04-21","ref":"changelog.html#fixed"},{"type":"extras","title":"Changed - Changelog","doc":"- Optimized internal handling of database transactions.\n\n---\n\n## [0.3.3] - 2024-04-21","ref":"changelog.html#changed"},{"type":"extras","title":"Added - Changelog","doc":"- Support for preflight HTTP requests.\n\n---\n\n## [0.3.2] - 2024-04-16","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- Resolved issues with JSON payload validation.\n\n---\n\n## [0.3.1] - 2024-04-15","ref":"changelog.html#fixed"},{"type":"extras","title":"Fixed - Changelog","doc":"- Resolved inconsistent query results in edge cases.\n\n---\n\n## [0.3.0] - 2023-11-20","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- Major refactor introducing modular architecture.\n- Support for real-time database change notifications.\n\n---\n\n## [0.2.3] - 2023-10-11","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- Patched security vulnerabilities in session handling.\n\n---\n\n## [0.2.2] - 2023-10-10","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- Middleware support for request customization.\n\n---\n\n## [0.2.1] - 2023-10-10","ref":"changelog.html#added"},{"type":"extras","title":"Fixed - Changelog","doc":"- Corrected behavior for long-lived connections.\n\n---\n\n## [0.2.0] - 2023-10-05","ref":"changelog.html#fixed"},{"type":"extras","title":"Added - Changelog","doc":"- Initial implementation of role-based access control.\n\n---\n\n## [0.1.0] - 2023-09-18","ref":"changelog.html#added"},{"type":"extras","title":"Added - Changelog","doc":"- Initial release with core features: database access, authentication, and storage support.","ref":"changelog.html#added"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}